(class-solution)=

# `Solution` Class Reference

This page contains detailed information on each of the methods, attributes, and properties in `Solution`. Use the sidebar on the right for easier navigation.

## Solution

```{eval-rst}
.. autoclass:: pyEQL.Solution
   :members:
   :inherited-members:
   :private-members: _get_property
   :special-members: __init__
   :member-order: bysource
```
